@@ -2,6 +2,7 @@
 
 pub use crate::rpc::pb::authpb::permission::Type as PermissionType;
 
+use crate::auth::AuthService;
 use crate::error::Result;
 use crate::rpc::pb::authpb::{Permission as PbPermission, UserAddOptions as PbUserAddOptions};
 use crate::rpc::pb::etcdserverpb::auth_client::AuthClient as PbAuthClient;
@@ -32,26 +33,23 @@ use crate::rpc::pb::etcdserverpb::{
 };
 use crate::rpc::ResponseHeader;
 use crate::rpc::{get_prefix, KeyRange};
-use std::string::String;
+use http::HeaderValue;
+use std::{string::String, sync::Arc};
 use tonic::transport::Channel;
-use tonic::{Interceptor, IntoRequest, Request};
+use tonic::{IntoRequest, Request};
 
 /// Client for Auth operations.
 #[repr(transparent)]
 #[derive(Clone)]
 pub struct AuthClient {
-    inner: PbAuthClient<Channel>,
+    inner: PbAuthClient<AuthService<Channel>>,
 }
 
 impl AuthClient {
     /// Creates an auth client.
     #[inline]
-    pub(crate) fn new(channel: Channel, interceptor: Option<Interceptor>) -> Self {
-        let inner = match interceptor {
-            Some(it) => PbAuthClient::with_interceptor(channel, it),
-            None => PbAuthClient::new(channel),
-        };
-
+    pub(crate) fn new(channel: Channel, auth_token: Option<Arc<HeaderValue>>) -> Self {
+        let inner = PbAuthClient::new(AuthService::new(channel, auth_token));
         Self { inner }
     }
 
@@ -299,6 +297,7 @@ impl IntoRequest<PbAuthEnableRequest> for AuthEnableOptions {
 }
 
 /// Response for `AuthEnable` operation.
+#[cfg_attr(feature = "pub-response-field", visible::StructFields(pub))]
 #[derive(Debug, Default, Clone)]
 #[repr(transparent)]
 pub struct AuthEnableResponse(PbAuthEnableResponse);
@@ -350,6 +349,7 @@ impl IntoRequest<PbAuthDisableRequest> for AuthDisableOptions {
 }
 
 /// Response for `AuthDisable` operation.
+#[cfg_attr(feature = "pub-response-field", visible::StructFields(pub))]
 #[derive(Debug, Default, Clone)]
 #[repr(transparent)]
 pub struct AuthDisableResponse(PbAuthDisableResponse);
@@ -413,6 +413,7 @@ impl IntoRequest<PbAuthenticateRequest> for AuthenticateOptions {
 }
 
 /// Response for `Authenticate` operation.
+#[cfg_attr(feature = "pub-response-field", visible::StructFields(pub))]
 #[derive(Debug, Default, Clone)]
 #[repr(transparent)]
 pub struct AuthenticateResponse(PbAuthenticateResponse);
@@ -473,6 +474,7 @@ impl IntoRequest<PbAuthRoleAddRequest> for RoleAddOptions {
 }
 
 /// Response for role add operation.
+#[cfg_attr(feature = "pub-response-field", visible::StructFields(pub))]
 #[derive(Debug, Clone)]
 #[repr(transparent)]
 pub struct RoleAddResponse(PbAuthRoleAddResponse);
@@ -525,6 +527,7 @@ impl IntoRequest<PbAuthRoleDeleteRequest> for RoleDeleteOptions {
 }
 
 /// Response for delete role operation.
+#[cfg_attr(feature = "pub-response-field", visible::StructFields(pub))]
 #[derive(Debug, Clone)]
 #[repr(transparent)]
 pub struct RoleDeleteResponse(PbAuthRoleDeleteResponse);
@@ -789,6 +792,7 @@ impl From<Permission> for PbPermission {
 }
 
 /// Response for get role operation.
+#[cfg_attr(feature = "pub-response-field", visible::StructFields(pub))]
 #[derive(Debug, Clone)]
 #[repr(transparent)]
 pub struct RoleGetResponse(PbAuthRoleGetResponse);
@@ -827,6 +831,7 @@ impl RoleGetResponse {
 use PbAuthRoleListRequest as AuthRoleListOptions;
 
 /// Response for list role operation.
+#[cfg_attr(feature = "pub-response-field", visible::StructFields(pub))]
 #[derive(Debug, Clone)]
 #[repr(transparent)]
 pub struct RoleListResponse(PbAuthRoleListResponse);
@@ -888,6 +893,7 @@ impl IntoRequest<PbAuthRoleGrantPermissionRequest> for RoleGrantPermissionOption
 }
 
 /// Response for grant role permission operation.
+#[cfg_attr(feature = "pub-response-field", visible::StructFields(pub))]
 #[derive(Debug, Clone)]
 #[repr(transparent)]
 pub struct RoleGrantPermissionResponse(PbAuthRoleGrantPermissionResponse);
@@ -995,6 +1001,7 @@ impl IntoRequest<PbAuthRoleRevokePermissionRequest> for RoleRevokePermissionOpti
 }
 
 /// Response for revoke role permission operation.
+#[cfg_attr(feature = "pub-response-field", visible::StructFields(pub))]
 #[derive(Debug, Clone)]
 #[repr(transparent)]
 pub struct RoleRevokePermissionResponse(PbAuthRoleRevokePermissionResponse);
@@ -1072,6 +1079,7 @@ impl IntoRequest<PbAuthUserAddRequest> for UserAddOptions {
 }
 
 /// Response for use add operation.
+#[cfg_attr(feature = "pub-response-field", visible::StructFields(pub))]
 #[derive(Debug, Clone)]
 #[repr(transparent)]
 pub struct UserAddResponse(PbAuthUserAddResponse);
@@ -1124,6 +1132,7 @@ impl IntoRequest<PbAuthUserGetRequest> for UserGetOptions {
 }
 
 /// Response for get user operation.
+#[cfg_attr(feature = "pub-response-field", visible::StructFields(pub))]
 #[derive(Debug, Clone)]
 #[repr(transparent)]
 pub struct UserGetResponse(PbAuthUserGetResponse);
@@ -1158,6 +1167,7 @@ impl UserGetResponse {
 use PbAuthUserListRequest as AuthUserListOptions;
 
 /// Response for list user operation.
+#[cfg_attr(feature = "pub-response-field", visible::StructFields(pub))]
 #[derive(Debug, Clone)]
 #[repr(transparent)]
 pub struct UserListResponse(PbAuthUserListResponse);
@@ -1216,6 +1226,7 @@ impl IntoRequest<PbAuthUserDeleteRequest> for UserDeleteOptions {
 }
 
 /// Response for delete user operation.
+#[cfg_attr(feature = "pub-response-field", visible::StructFields(pub))]
 #[derive(Debug, Clone)]
 #[repr(transparent)]
 pub struct UserDeleteResponse(PbAuthUserDeleteResponse);
@@ -1271,6 +1282,7 @@ impl IntoRequest<PbAuthUserChangePasswordRequest> for UserChangePasswordOptions
 }
 
 /// Response for change user's password operation.
+#[cfg_attr(feature = "pub-response-field", visible::StructFields(pub))]
 #[derive(Debug, Clone)]
 #[repr(transparent)]
 pub struct UserChangePasswordResponse(PbAuthUserChangePasswordResponse);
@@ -1323,6 +1335,7 @@ impl IntoRequest<PbAuthUserGrantRoleRequest> for UserGrantRoleOptions {
 }
 
 /// Response for grant role for an user operation.
+#[cfg_attr(feature = "pub-response-field", visible::StructFields(pub))]
 #[derive(Debug, Clone)]
 #[repr(transparent)]
 pub struct UserGrantRoleResponse(PbAuthUserGrantRoleResponse);
@@ -1375,6 +1388,7 @@ impl IntoRequest<PbAuthUserRevokeRoleRequest> for UserRevokeRoleOptions {
 }
 
 /// Response for revoke role for an user operation.
+#[cfg_attr(feature = "pub-response-field", visible::StructFields(pub))]
 #[derive(Debug, Clone)]
 #[repr(transparent)]
 pub struct UserRevokeRoleResponse(PbAuthUserRevokeRoleResponse);
